GatewayClient class

Cliente HTTP base para comunicação direta com o Gateway de Pagamentos.

Constructors

GatewayClient({String? gatewayBaseUrl, String? apiKey, Duration connectTimeout = const Duration(seconds: 30), Duration receiveTimeout = const Duration(seconds: 30), Duration sendTimeout = const Duration(seconds: 30)})

Properties

apiKey String?
final
dio → Dio
no setter
gatewayBaseUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited