TsdtechClient class
Properties
- gateway ↔ GatewayService?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- orchestrator ↔ CheckoutOrchestrator?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage ↔ Environment?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → TsdtechClient
-
no setter
Static Methods
-
initialize(
{required String baseUrl, String? gatewayBaseUrl, String? gatewayApiKey, TsdtechThemeData? theme, TsdtechLocale locale = TsdtechLocale.pt, Environment? stage}) → void