GatewayService class

Serviço responsável por orquestrar chamadas de pagamento com o Gateway.

Constructors

GatewayService(GatewayClient _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchPublicKey() → Future<ValueResult<PublicKeyResponse>>
getPaymentStatus(String depositRequestId) → Future<ValueResult<PaymentStatusResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payWithCard(CardPaymentRequest request) → Future<ValueResult<PaymentStatusResponse>>
payWithEncryptedCard(String depositRequestId, CardPaymentData cardData, String pemPublicKey, String keyId) → Future<ValueResult<PaymentStatusResponse>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → GatewayService
no setter

Static Methods

init(GatewayClient client) → void