IntraApiModule class
- Inheritance
-
- Object
- ModuleBase
- IntraApiModule
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ List<
ModuleBase> -
no setteroverride
-
routes
→ List<
AutoRoute> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collectRoutes(
) → List< AutoRoute> -
inherited
-
inject(
GetIt sl) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerStores(
GetIt sl) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited