CardPaymentRequest class
Payload enviado para processar um pagamento com cartão criptografado.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- CardPaymentRequest({required String depositRequestId, required String encryptedCard, required String keyId, int? installmentNumber})
-
CardPaymentRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- depositRequestId → String
-
final
- encryptedCard → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installmentNumber → int?
-
final
- keyId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited