Administrator class

Annotations
  • @JsonSerializable.new()

Constructors

Administrator({required String id, String? email, String? name, String? cnpj, String? phoneContact, List<String>? clients, List<String>? fullDomain, DateTime? createdAt, DateTime? updatedAt})
Administrator.fromJson(Map<String, dynamic> json)
factory

Properties

clients List<String>?
final
cnpj String?
final
createdAt DateTime?
final
email String?
final
fullDomain List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String?
final
phoneContact String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited