ApiKey class

Annotations
  • @JsonSerializable.new()

Constructors

ApiKey({required String id, String? organizationId, required String name, String? rawKey})
ApiKey.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
organizationId String?
final
rawKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited