ClientUserEntity class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ClientUserEntity({String? firstName, String? lastName, String? email, String? phone, String? document, String? documentType, String? twoFactorAuthKey, String? developerPassword, String? administratorId, List<String>? memberships})
ClientUserEntity.fromJson(Map<String, dynamic> json)
factory

Properties

administratorId String?
final
developerPassword String?
final
document String?
final
documentType String?
final
email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
lastName String?
final
memberships List<String>?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
twoFactorAuthKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited