ClientUserTokenData class

Annotations
  • @JsonSerializable.new()

Constructors

ClientUserTokenData({String? id, String? name, String? secondName, String? email, String? phone, String? cpf, bool? is2FAAuthorized, int? expiresAt})
ClientUserTokenData.fromJson(Map<String, dynamic> json)
factory

Properties

cpf String?
final
email String?
final
expiresAt int?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
is2FAAuthorized bool?
final
name String?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondName String?
final

Methods

isTokenExpired() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited