CardPaymentData class

Annotations
  • @JsonSerializable.new()

Constructors

CardPaymentData({required String cardHolderName, required String cardNumber, required String cardExpiryDate, required String securityCode, bool? preAuthorizedTransaction})
CardPaymentData.fromJson(Map<String, dynamic> json)
factory

Properties

cardExpiryDate → String
final
cardHolderName → String
final
cardNumber → String
final
hashCode → int
The hash code for this object.
no setterinherited
preAuthorizedTransaction → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityCode → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited