PaymentMethodModel class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PaymentMethodModel({required String paymentMethod, required bool isActive, int? installmentNumber})
-
PaymentMethodModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- installmentNumber → int?
-
final
- isActive → bool
-
final
- paymentMethod → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited