ServiceForm class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ServiceForm({required String id, required String title, String? clientId, String? description, Map<String, dynamic>? metadata, required List<ServiceFormField> fields, DateTime? createdAt, DateTime? updatedAt})
ServiceForm.fromJson(Map<String, dynamic> json)
The API can return either the form directly or an envelope { id, form: { ... } }.
factory

Properties

clientId String?
final
createdAt DateTime?
final
description String?
final
fields List<ServiceFormField>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited