ServiceFormField class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ServiceFormField({required String id, required String type, required String label, bool isRequired = false, List<String>? options, String? validationKey})
ServiceFormField.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isRequired bool
final
label String
final
options List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
validationKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited