NavItem enum

Navigation items enum with integer values.

Inheritance
Available extensions

Values

home → const NavItem
const NavItem(0)
myVouchers → const NavItem
const NavItem(1)
payments → const NavItem
const NavItem(2)
profile → const NavItem
const NavItem(3)
settings → const NavItem
const NavItem(4)
logout → const NavItem
const NavItem(5)
cart → const NavItem
const NavItem(6)
login → const NavItem
const NavItem(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
key String

Available on NavItem, provided by the NavItemExt extension

Optional: return a debug-friendly name
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NavItem>
A constant List of the values in this enum, in order of their declaration.