OrderPaymentInfo class

Annotations
  • @JsonSerializable.new()

Constructors

OrderPaymentInfo({required String id, String? paymentMethod, double? cartTotalValue, int? installmentNumber})
OrderPaymentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

cartTotalValue double?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
installmentNumber int?
final
paymentMethod String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited