isError property
bool
get
isError
Returns true if this result represents a failure with an error.
Implementation
bool get isError => _error != null;
Returns true if this result represents a failure with an error.
bool get isError => _error != null;