isSuccess property
bool
get
isSuccess
Returns true if this result represents a success with a value.
Implementation
bool get isSuccess => _error == null;
Returns true if this result represents a success with a value.
bool get isSuccess => _error == null;