title property
String?
get
title
Returns the optional error title.
May be null even in error states if no title was provided.
Implementation
String? get title => _title;
Returns the optional error title.
May be null even in error states if no title was provided.
String? get title => _title;