ProviderRequest class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ProviderRequest({required String id, String? voucherId, String? providerId, String? serviceId, String? formId, String? clientId, String? administratorId, String? createdAt, String? updatedAt, Voucher? voucher, Map<String, dynamic>? provider, Service? service, ClientUserEntity? client, String voucherServiceId = '', String serviceName = '', String status = '', String result = '', String inspector = '', DateTime? inspectionDate, DateTime? appointmentDate, DateTime? completedDate, String plate = '', String renavam = '', String model = '', String year = '', String observacoes = ''})
ProviderRequest.fromJson(Map<String, dynamic> json)
factory

Properties

administratorId String?
final
appointmentDate DateTime?
final
client ClientUserEntity?
final
clientId String?
final
completedDate DateTime?
final
createdAt String?
final
formId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
inspectionDate DateTime?
final
inspector String
final
model String
final
observacoes String
final
plate String
final
provider Map<String, dynamic>?
final
providerId String?
final
renavam String
final
result String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service Service?
final
serviceId String?
final
serviceName String
final
status String
final
updatedAt String?
final
voucher Voucher?
final
voucherId String?
final
voucherServiceId String
final
year String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited