tsdtech_sdk_client library
Classes
- AddressModel
- BaseApi
- Static HTTP client base class using Dio for making API requests.
- CalculateItem
- CalculateRequest
- CalculateResponse
- CardEncryptor
- CardPaymentData
- CardPaymentRequest
- Payload enviado para processar um pagamento com cartão criptografado.
- CartItem
- CheckoutOrchestrator
- Orchestrates the full card payment flow: checkout → fetch public key → encrypt → pay.
- CheckoutRequest
- CheckoutResponse
- CheckoutsService
- Service for handling checkout and payment operations.
- Constants
- GatewayClient
- Cliente HTTP base para comunicação direta com o Gateway de Pagamentos.
- GatewayService
- Serviço responsável por orquestrar chamadas de pagamento com o Gateway.
- IntraApi
- Base class for intra-service API communication.
-
PaginatedList<
T> - Pagination
- PaymentMethodModel
- PaymentStatusResponse
- DTO contendo o status final do processamento no Gateway.
- PixData
- PublicKeyResponse
- DTO que representa a resposta da chave pública RSA do Gateway.
- SearchUtils
- TsdtechClient
- UnixDateTimeConverter
- Non-nullable converter (int <-> DateTime)
- UnixDateTimeNullableConverter
- Nullable converter (int? <-> DateTime?)
-
ValueResult<
T> - A result type that represents either a success value or a failure error.
Functions
-
formatDate(
DateTime? date) → String