CardFormStoreBase class abstract

Implementers

Constructors

CardFormStoreBase()

Properties

brand ↔ CardBrand
getter/setter pair
cardholderName ↔ String
getter/setter pair
cardNumber ↔ String
getter/setter pair
context → ReactiveContext
Override this method to use a custom context.
no setterinherited
cvv ↔ String
getter/setter pair
cvvFieldVersion ↔ int
getter/setter pair
data → CardFormData
no setter
expiryDate ↔ String
getter/setter pair
formKey → GlobalKey<FormState>
final
formVersion ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAmex → bool
no setter
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxId ↔ String
getter/setter pair

Methods

clearCvv() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
resetForm() → void
setBrand(CardBrand value) → void
setData(CardFormData value) → void
toString() → String
A string representation of this object.
inherited
updateCardholderName(String value) → void
updateCardNumber(String value) → void
updateCvv(String value) → void
updateExpiryDate(String value) → void
updateTaxId(String value) → void
validateForm() → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited