toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return '''
selectedMethod: ${selectedMethod},
isLoading: ${isLoading},
errorMessage: ${errorMessage},
pixQrCode: ${pixQrCode},
pixCopyPasteCode: ${pixCopyPasteCode},
pixExpirationDate: ${pixExpirationDate},
paymentId: ${paymentId},
paymentResult: ${paymentResult},
cardHolderName: ${cardHolderName},
cardNumber: ${cardNumber},
expiryDate: ${expiryDate},
feeAmount: ${feeAmount},
securityCode: ${securityCode},
cardFormVersion: ${cardFormVersion},
taxId: ${taxId},
amount: ${amount},
totalAmount: ${totalAmount},
items: ${items},
hasError: ${hasError},
hasGeneratedPix: ${hasGeneratedPix},
isPixSelected: ${isPixSelected},
isCardSelected: ${isCardSelected}
  ''';
}