CardPaymentView class

Inheritance

Constructors

CardPaymentView({Key? key, required GlobalKey<FormState> formKey, required int formVersion, required String cardHolderName, required String cardNumber, required String expiryDate, required String securityCode, required String taxId, required ValueChanged<String> onCardHolderChanged, required ValueChanged<String> onCardNumberChanged, required ValueChanged<String> onExpiryChanged, required ValueChanged<String> onSecurityCodeChanged, required ValueChanged<String> onTaxIdChanged})
const

Properties

cardHolderName String
final
cardNumber String
final
expiryDate String
final
formKey GlobalKey<FormState>
final
formVersion int
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCardHolderChanged ValueChanged<String>
final
onCardNumberChanged ValueChanged<String>
final
onExpiryChanged ValueChanged<String>
final
onSecurityCodeChanged ValueChanged<String>
final
onTaxIdChanged ValueChanged<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityCode String
final
taxId String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited