CheckoutWidget class

Inheritance

Constructors

CheckoutWidget({Key? key, List<CartItem>? items, String? administratorId, String? depositRequestId, String? gatewayPublicKey, void onSuccess(PaymentResult)?, void onError(String)?, void onStatusChange(PaymentStatus)?, bool showPix = true, bool showCard = true, Widget? loadingWidget, Widget? errorWidget, bool showSubmitButton = true, CheckoutWidgetController? controller, CheckoutStore? store})
const

Properties

administratorId String?
final
controller CheckoutWidgetController?
final
depositRequestId String?
final
errorWidget Widget?
final
gatewayPublicKey String?
final
hashCode int
The hash code for this object.
no setterinherited
items List<CartItem>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget?
final
onError → void Function(String)?
final
onStatusChange → void Function(PaymentStatus)?
final
onSuccess → void Function(PaymentResult)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCard bool
final
showPix bool
final
showSubmitButton bool
final
store CheckoutStore?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CheckoutWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited