CheckoutWidgetController class

Constructors

CheckoutWidgetController()

Properties

hasGeneratedPix → ValueNotifier<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
hasSelectedMethod → ValueNotifier<bool>
final
isLoading → ValueNotifier<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedMethod → ValueNotifier<PaymentMethodType>
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
submitPayment() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited