PaymentResult class

Constructors

PaymentResult({required String transactionId, required PaymentMethodType method, required PaymentStatus status, String? pixQrCode, String? depositRequestId, String? message})

Properties

depositRequestId String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
method PaymentMethodType
final
pixQrCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentStatus
final
transactionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited