TsdtechColors class abstract final

TSDTech brand color palette.

Use the semantic tokens (e.g. TsdtechColors.primary) instead of raw hex values to stay consistent across light/dark variants.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const Color
accentDark → const Color
accentLight → const Color
darkBackground → const Color
darkOutline → const Color
darkSurface → const Color
darkSurfaceVariant → const Color
darkTextDisabled → const Color
darkTextPrimary → const Color
darkTextSecondary → const Color
error → const Color
errorLight → const Color
info → const Color
infoLight → const Color
outline → const Color
outlineVariant → const Color
primary → const Color
primaryDark → const Color
primaryLight → const Color
success → const Color
successLight → const Color
surface → const Color
surfaceVariant → const Color
textDisabled → const Color
textOnPrimary → const Color
textPrimary → const Color
textSecondary → const Color
warning → const Color
warningLight → const Color
white → const Color