menu
tsdtech_client_sdk package
documentation
crypto/card_encryptor.dart
CardEncryptor class
CardEncryptor class
dark_mode
light_mode
CardEncryptor
class
Constructors
CardEncryptor
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Static Methods
encrypt
(
String
pemPublicKey
,
CardPaymentData
cardData
)
→
String
Criptografa os dados do cartão usando chave pública RSA. Utiliza o padrão exigido para PCI: RSA/ECB/OAEPWithSHA-256AndMGF1Padding. Retorna o ciphertext em Base64.
tsdtech_client_sdk package
documentation
crypto/card_encryptor
CardEncryptor class
card_encryptor library