SignupRequestClient class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- SignupRequestClient({required String firstName, required String lastName, required String email, required String password, required String document, required String cellphone, required String documentType, required String administratorId})
-
SignupRequestClient.fromJson(Map<
String, dynamic> json) -
factory
Properties
- administratorId → String
-
final
- cellphone → String
-
final
- document → String
-
final
- documentType → String
-
final
- email → String
-
final
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
final
- password → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited