CheckoutRequest class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CheckoutRequest({required List<CalculateItem> cart, required String paymentMethod, required double totalValue, String? encryptedCard, CardPaymentData? card, String? depositRequestId, int? installmentNumber})
CheckoutRequest.fromJson(Map<String, dynamic> json)
factory

Properties

card CardPaymentData?
final
cart List<CalculateItem>
final
depositRequestId String?
final
encryptedCard String?
final
hashCode int
The hash code for this object.
no setterinherited
installmentNumber int?
final
paymentMethod String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalValue double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited