CheckoutResponse class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CheckoutResponse({required String paymentMethod, String? paymentId, PixData? pix, String? status, String? depositRequestId, String? gatewayBaseUrl, String? publicKeyUrl})
CheckoutResponse.fromJson(Map<String, dynamic> json)
factory

Properties

depositRequestId String?
final
gatewayBaseUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
paymentId String?
final
paymentMethod String
final
pix PixData?
final
publicKeyUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited