AddressModel class
- Annotations
-
- @JsonSerializable.new()
Constructors
- AddressModel({required String id, required DateTime createdAtUtc, String countryCode = 'BR', required String street, required String number, required String complement, required String district, required String city, required String state, required String zipCode})
-
AddressModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- city → String
-
final
- complement → String
-
final
- countryCode → String
-
final
- createdAtUtc → DateTime
-
final
- district → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- number → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
final
- street → String
-
final
- zipCode → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited