OrderModel class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- OrderModel({required String id, String? hash, String? status, String? clientId, String? orderPaymentInfoId, DateTime? createdAt, DateTime? updatedAt, OrderClientInfo? client, OrderPaymentInfo? orderPaymentInfo})
-
OrderModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- client → OrderClientInfo?
-
final
- clientId → String?
-
final
- createdAt → DateTime?
-
final
- hash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- orderPaymentInfo → OrderPaymentInfo?
-
final
- orderPaymentInfoId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- updatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited