Service class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Service({String? id, String? name, String? code, String? description, String? administratorId, String? serviceTypeId, ServiceType? serviceType, double? price, List<String>? tags, int? validTimestamp, String? status, DateTime? createdAt, DateTime? updatedAt})
Service.fromJson(Map<String, dynamic> json)
factory

Properties

administratorId String?
final
code String?
final
createdAt DateTime?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String?
final
price double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceType ServiceType?
final
serviceTypeId String?
final
status String?
final
tags List<String>?
final
updatedAt DateTime?
final
validTimestamp int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited