PaymentStore class
- Inheritance
-
- Object
- PaymentStoreBase
- PaymentStore
Constructors
- PaymentStore({PaymentFormMethod initialMethod = PaymentFormMethod.pix, CardFormStore? cardFormStore})
Properties
- canInteract → bool
-
no setterinherited
- cardFormStore → CardFormStore
-
finalinherited
- context → ReactiveContext
-
Override this method to use a custom context.
no setterinherited
- currentData → PaymentFormData
-
no setterinherited
- enabled ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCardSelected → bool
-
no setterinherited
- isLoading ↔ bool
-
getter/setter pairinherited
- isPixSelected → bool
-
no setterinherited
- lastSubmittedData ↔ PaymentFormData?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedCardData → CardFormData?
-
no setterinherited
- selectedMethod ↔ PaymentFormMethod
-
getter/setter pairinherited
Methods
-
clearSubmission(
) → void -
inherited
-
markSubmitted(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
inherited
-
selectMethod(
PaymentFormMethod method) → void -
inherited
-
setCardData(
CardFormData value) → void -
inherited
-
setEnabled(
bool value) → void -
inherited
-
setLoading(
bool value) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited