PaymentStoreBase class abstract

Implementers

Constructors

PaymentStoreBase({PaymentFormMethod initialMethod = PaymentFormMethod.pix, CardFormStore? cardFormStore})

Properties

canInteract bool
no setter
cardFormStore CardFormStore
final
context → ReactiveContext
Override this method to use a custom context.
no setterinherited
currentData PaymentFormData
no setter
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isCardSelected bool
no setter
isLoading bool
getter/setter pair
isPixSelected bool
no setter
lastSubmittedData PaymentFormData?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCardData CardFormData?
no setter
selectedMethod PaymentFormMethod
getter/setter pair

Methods

clearSubmission() → void
markSubmitted() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
selectMethod(PaymentFormMethod method) → void
setCardData(CardFormData value) → void
setEnabled(bool value) → void
setLoading(bool value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited